@@ -1,8 +1,8 @@
 package Date::Holidays::GB;
 
-our $VERSION = '0.023';
+our $VERSION = '0.024';
 
-# ABSTRACT: Determine British holidays - Current UK public and bank holiday dates up to 2023
+# ABSTRACT: Determine British holidays - Current UK public and bank holiday dates up to 2026
 
 use strict;
 use warnings;
@@ -196,7 +196,7 @@ sub _holiday {
     return join( ', ', @strings );
 }
 
-sub date_generated { '2023-01-04' }
+sub date_generated { '2024-04-08' }
 
 1;
 
@@ -591,3 +591,30 @@ __DATA__
 2025-12-26	EAW	Boxing Day
 2025-12-26	NIR	Boxing Day
 2025-12-26	SCT	Boxing Day
+2026-01-01	EAW	New Year’s Day
+2026-01-01	NIR	New Year’s Day
+2026-01-01	SCT	New Year’s Day
+2026-01-02	SCT	2nd January
+2026-03-17	NIR	St Patrick’s Day
+2026-04-03	EAW	Good Friday
+2026-04-03	NIR	Good Friday
+2026-04-03	SCT	Good Friday
+2026-04-06	EAW	Easter Monday
+2026-04-06	NIR	Easter Monday
+2026-05-04	EAW	Early May bank holiday
+2026-05-04	NIR	Early May bank holiday
+2026-05-04	SCT	Early May bank holiday
+2026-05-25	EAW	Spring bank holiday
+2026-05-25	NIR	Spring bank holiday
+2026-05-25	SCT	Spring bank holiday
+2026-07-13	NIR	Battle of the Boyne (Orangemen’s Day)
+2026-08-03	SCT	Summer bank holiday
+2026-08-31	EAW	Summer bank holiday
+2026-08-31	NIR	Summer bank holiday
+2026-11-30	SCT	St Andrew’s Day
+2026-12-25	EAW	Christmas Day
+2026-12-25	NIR	Christmas Day
+2026-12-25	SCT	Christmas Day
+2026-12-28	EAW	Boxing Day
+2026-12-28	NIR	Boxing Day
+2026-12-28	SCT	Boxing Day
