@@ -1,7 +1,7 @@
 #!/usr/bin/perl
 
 # script to update Date::Holidays::GB with the latest bank holiday dates from
-# http://www.gov.uk/bank-holidays
+# https://www.gov.uk/bank-holidays
 
 use strict;
 use warnings;
@@ -14,7 +14,7 @@ use List::MoreUtils qw( uniq );
 use LWP::Simple qw( get );
 use Time::Local ();
 
-my $URL = 'http://www.gov.uk/bank-holidays.json';
+my $URL = 'https://www.gov.uk/bank-holidays.json';
 
 my %CODE = (
     'england-and-wales' => 'EAW',
